@@ -1,3 +1,4 @@
+from leetcode import *
 class Answer:
     def __init__(self,title,Description,author):
         self.Title=title
@@ -33,4 +34,6 @@ class Answer:
         if wrong==0:
             print("\nThis Challenge Has Been Solved By "+self.Author)
         else:
-            print("\n"+self.Author+"! Try again!")
\ No newline at end of file
+            print("\n"+self.Author+"! Try again!")
+
+print("Done.")
\ No newline at end of file
